# Kanban card
#
# Textile markupped text describing a card.
# a card is a line of text starting with a dash "-"
#
# - @adolfo fix this #bug: 234 (c:2013-02-15)
#
# the card embeds information such as:
#
# * owner: @name
# * swimlane: +swimlane (at most one)
# * tags: #tag1, #tag2 (TODO)
#
# * creation date: c:
# * finish date: f:
# * due date: d:
#
# the card stores also information which is defined elsewhere in the kanban file.
# This information includes:
#
# - project: the project the card refers to (set with a h1. tag in the file)
# - status: the current status of the card (set with a h2. tag in the file)
#

class Kanboard::Card
  GENERIC_SWIMLANE = "Generic" # the swimlane for cards with no swimlane
  NO_ONE = "Unassigned" # the owned of cards not owned by anyone

  attr_accessor :project, :status

  def initialize(project, status, title)
    @project = project
    @status = status
    @title = title[2, title.length] # forget about the initial "- "
  end

  def owner
    find("@", @title) || NO_ONE
  end

  def swimlane
    find("\\+", @title) || GENERIC_SWIMLANE
  end

  def created
    find("c:", @title)
  end

  def finished
    find("f:", @title)
  end

  def done?
    finished != nil
  end

  def due
    find("d:", @title)
  end

  def to_s
    @title
  end

  private

  # find a substring of the type tag[\w]+ in argument
  # return nil if not found.
  def find(tag, string)
    match = string.match(Regexp.new(tag + "([\\w]+)"))
    match ? match[1] : nil
  end

end
